@@ -2,13 +2,15 @@ package CPAN::Audit;
 use 5.008001;
 use strict;
 use warnings;
+use version;
 use CPAN::Audit::Installed;
 use CPAN::Audit::Discover;
 use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPAN::Audit::DB;
+use Module::CoreList;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 sub new {
     my $class = shift;
@@ -41,6 +43,18 @@ sub command {
 
     my %dists;
 
+    # Find core modules for this perl version first.
+    # This way explictly installed versions will overwrite.
+    if ( $command eq 'dependencies' || $command eq 'deps' || $command eq 'installed' ) {
+        if ( my $core = $Module::CoreList::version{$]} ) {
+            while ( my ( $mod, $ver ) = each %$core ) {
+                my $dist = $self->{db}{module2dist}{$mod} or next;
+
+                $dists{$dist} = $ver if version->parse($ver) > $dists{$dist};
+            }
+        }
+    }
+
     if ( $command eq 'module' ) {
         my ( $module, $version_range ) = @args;
         $self->fatal("Usage: module <module> [version-range]") unless $module;
@@ -279,4 +293,6 @@ Viacheslav Tykhanovskyi E<lt>viacheslav.t@gmail.comE<gt>
 
 Takumi Akiyama (github.com/akiym)
 
+James Raspass (github.com/JRaspass)
+
 =cut
